pub struct TtyHandles {
pub tty_in: File,
pub tty_out: File,
}Expand description
File handles for the controlling terminal that the spawned editor child
will inherit. On Unix these wrap the file descriptors for /dev/tty
opened twice (read + write); on Windows they wrap CONIN$ and CONOUT$.
Fields
tty_in: Filetty_out: FileTrait Implementations